@@ -1269,7 +1269,6 @@ activate_action_about (GtkAction *action,
 {
 	FRWindow         *window = data;
 	static GtkWidget *about = NULL;
-	GdkPixbuf        *logo;
 	const char       *authors[] = {
 		"Paolo Bacchilega <paolo.bacchilega@libero.it>", NULL
 	};
@@ -1280,22 +1279,26 @@ activate_action_about (GtkAction *action,
 	};
 	const char       *translator_credits = _("translator_credits");
 
+
 	if (about != NULL) {
 		gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
 
-	logo = gdk_pixbuf_new_from_file (PIXMAPSDIR "/file-roller.png", NULL);
-	about = gnome_about_new (_("File Roller"), 
-				 VERSION,
-				 "Copyright \xc2\xa9 2001-2004 Free Software Foundation, Inc.",
-				 _("An archive manager for GNOME."),
-				 authors,
-				 documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				 logo);
-	if (logo != NULL)
-                g_object_unref (logo);
+	about = gtk_about_dialog_new ();
+	g_object_set (about,
+		      "name",  _("File Roller"),
+		      "version", VERSION,
+		      "copyright", "Copyright \xc2\xa9 2001-2004 Free Software Foundation, Inc.",
+		      "comments", ("An archive manager for GNOME."),
+		      "authors", authors,
+		      "documenters", documenters,
+		      "translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		      "logo_icon_name", "file-roller",
+		      "website", NULL,
+		      "website_label", NULL,
+		      "license", NULL,
+		      NULL);
 
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (about), TRUE);
 	gtk_window_set_transient_for (GTK_WINDOW (about), 
@@ -1306,5 +1309,5 @@ activate_action_about (GtkAction *action,
 			  G_CALLBACK (gtk_widget_destroyed), 
 			  &about);
 
-	gtk_widget_show_all (about);
+	gtk_widget_show (about);
 }
