@@ -40,28 +40,28 @@
 
 
 typedef struct {
-	FRWindow  *window;
-	GtkWidget *dialog;
-	GtkWidget *include_subfold_checkbutton;
-	GtkWidget *add_if_newer_checkbutton;
-	GtkWidget *exclude_symlinks;
-	GtkWidget *include_files_checkbutton;
-	GtkWidget *include_files_entry;
-	GtkWidget *include_files_label;
-	GtkWidget *exclude_files_entry;
-	GtkWidget *exclude_files_label;
-	GtkWidget *load_button;
-	GtkWidget *save_button;
-	char      *last_options;
+	FRWindow    *window;
+	GtkTooltips *tooltips;
+	GtkWidget   *dialog;
+	GtkWidget   *include_subfold_checkbutton;
+	GtkWidget   *add_if_newer_checkbutton;
+	GtkWidget   *exclude_symlinks;
+	GtkWidget   *include_files_checkbutton;
+	GtkWidget   *include_files_entry;
+	GtkWidget   *include_files_label;
+	GtkWidget   *exclude_files_entry;
+	GtkWidget   *exclude_files_label;
+	GtkWidget   *load_button;
+	GtkWidget   *save_button;
+	char        *last_options;
 } DialogData;
 
 
 static void
-open_file_destroy_cb (GtkWidget *w,
-		      GtkWidget *file_sel)
+open_file_destroy_cb (GtkWidget  *widget,
+		      DialogData *data)
 {
-	DialogData *data;
-	data = g_object_get_data (G_OBJECT (file_sel), "fr_dialog_data");
+	g_object_unref (data->tooltips);
 	g_free (data->last_options);
 	g_free (data);
 }
@@ -86,27 +86,23 @@ utf8_only_spaces (const char *text)
 
 
 static int
-file_sel_response_cb (GtkWidget      *w,
-		      int             response,
-		      GtkFileChooser *file_sel)
+file_sel_response_cb (GtkWidget    *widget,
+		      int           response,
+		      DialogData   *data)
 {
-	FRWindow   *window;
-	char       *current_folder;
-	gboolean    update, recursive, follow_links;
-	GSList     *selections, *iter;
-	GList      *item_list = NULL;
-	DialogData *data;
+	GtkFileChooser *file_sel = GTK_FILE_CHOOSER (widget);
+	FRWindow       *window = data->window;
+	char           *current_folder;
+	gboolean        update, recursive, follow_links;
+	GSList         *selections, *iter;
+	GList          *item_list = NULL;
 
 
-	data = g_object_get_data (G_OBJECT (file_sel), "fr_dialog_data");
-
-	if (response == GTK_RESPONSE_CANCEL) {
+	if ((response == GTK_RESPONSE_CANCEL) || (response == GTK_RESPONSE_DELETE_EVENT)) {
 		gtk_widget_destroy (data->dialog);
 		return TRUE;
 	}
 
-	window = data->window;
-
 	current_folder = gtk_file_chooser_get_current_folder (file_sel);
 
 	/* check folder permissions. */
@@ -125,14 +121,12 @@ file_sel_response_cb (GtkWidget      *w,
 					     GTK_DIALOG_MODAL,
 					     GTK_STOCK_DIALOG_ERROR,
 					     _("Could not add the files to the archive"),
-					     _("You don't have the right permissions to read files from folder \"%s\""),
-					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					     GTK_STOCK_OK, GTK_RESPONSE_OK,
+					     message,
+					     GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
 					     NULL);
-		gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_OK);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (GTK_WIDGET (d));
-		g_free (utf8_path);
+		g_free (message);
 
 		g_free (current_folder);
 
@@ -238,6 +232,37 @@ static void
 selection_changed_cb (GtkWidget  *file_sel, 
 		      DialogData *data)
 {
+	FRWindow   *window = data->window;
+	char       *current_folder;
+
+        current_folder = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (file_sel));
+
+        /* check folder permissions. */
+                                                                                                
+        if (path_is_dir (current_folder)
+            && access (current_folder, R_OK | X_OK) != 0) {
+                GtkWidget *d;
+                char      *utf8_path;
+                char      *message;
+		
+                utf8_path = g_filename_to_utf8 (current_folder, -1, NULL, NULL, NULL);
+                message = g_strdup_printf (_("You don't have the right permissions to read files from folder \"%s\""), utf8_path);
+                g_free (utf8_path);
+		
+                d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+                                             GTK_DIALOG_MODAL,
+                                             GTK_STOCK_DIALOG_ERROR,
+                                             _("Could not add the files to the archive"),
+                                             message,
+                                             GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
+                                             NULL);
+                gtk_dialog_run (GTK_DIALOG (d));
+                gtk_widget_destroy (GTK_WIDGET (d));
+                g_free (message);
+		
+                g_free (current_folder);
+        }
+
 	update_sensitivity (data);
 }
 
@@ -276,12 +301,15 @@ add_folder_cb (GtkWidget *widget,
 	GtkWidget   *main_box;
 	GtkWidget   *vbox, *hbox;
 	GtkWidget   *table;	
-	GtkTooltips *tooltips;
-	
-	tooltips = gtk_tooltips_new ();
- 
+
 	data = g_new0 (DialogData, 1);
+
 	data->window = callback_data;
+
+	data->tooltips = gtk_tooltips_new ();
+	g_object_ref (G_OBJECT (data->tooltips));
+	gtk_object_sink (GTK_OBJECT (data->tooltips));
+
 	data->dialog = file_sel = 
 		gtk_file_chooser_dialog_new (_("Add a Folder"),
 					     GTK_WINDOW (data->window->app),
@@ -300,12 +328,12 @@ add_folder_cb (GtkWidget *widget,
 	data->exclude_symlinks = gtk_check_button_new_with_mnemonic (_("Exclude folders that are symbolic lin_ks"));
 
 	data->include_files_entry = gtk_entry_new ();
-	gtk_tooltips_set_tip (tooltips, data->include_files_entry, _("example: *.o; *.bak"), NULL);
+	gtk_tooltips_set_tip (data->tooltips, data->include_files_entry, _("example: *.o; *.bak"), NULL);
 	data->include_files_label = gtk_label_new_with_mnemonic (_("_Include files:"));
 	gtk_misc_set_alignment (GTK_MISC (data->include_files_label), 0.0, 0.5);
 
 	data->exclude_files_entry = gtk_entry_new ();
-	gtk_tooltips_set_tip (tooltips, data->exclude_files_entry, _("example: *.o; *.bak"), NULL);
+	gtk_tooltips_set_tip (data->tooltips, data->exclude_files_entry, _("example: *.o; *.bak"), NULL);
 	data->exclude_files_label = gtk_label_new_with_mnemonic (_("E_xclude files:"));
 	gtk_misc_set_alignment (GTK_MISC (data->exclude_files_label), 0.0, 0.5);
 
@@ -382,9 +410,7 @@ add_folder_cb (GtkWidget *widget,
 	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (file_sel), dir);
 	g_free (dir);
 
-	g_object_set_data (G_OBJECT (file_sel), "fr_dialog_data", data);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->include_subfold_checkbutton), FALSE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->include_subfold_checkbutton), TRUE);
 
 	update_sensitivity (data);
 
@@ -393,12 +419,12 @@ add_folder_cb (GtkWidget *widget,
 	g_signal_connect (G_OBJECT (file_sel),
 			  "destroy", 
 			  G_CALLBACK (open_file_destroy_cb),
-			  file_sel);
+			  data);
 
 	g_signal_connect (G_OBJECT (file_sel),
 			  "response",
 			  G_CALLBACK (file_sel_response_cb),
-			  file_sel);
+			  data);
 
 	g_signal_connect (G_OBJECT (file_sel), 
 			  "selection-changed",
@@ -428,17 +454,12 @@ add_folder_cb (GtkWidget *widget,
 			  "clicked",
 			  G_CALLBACK (save_options_cb), 
 			  data);
-	
-	g_object_set_data (G_OBJECT (file_sel), "tooltips", tooltips);
 
 	gtk_window_set_modal (GTK_WINDOW (file_sel),TRUE);
 	gtk_widget_show (file_sel);
 }
 
 
-
-
-
 typedef struct {
 	DialogData   *data;
 	GladeXML     *gui;
@@ -720,9 +741,6 @@ load_options_cb (GtkWidget  *w,
 }
 
 
-
-
-
 static void
 config_set_bool (const char *config_file,
 		 const char *option,
